Changelog
=========


(unreleased)
------------
- Feat: new version. [Jakob Graf]


0.1.14 (2024-01-28)
-------------------
- Release: version 0.1.14 🚀 [Jakob Graf]
- Bug: timing plugin. [Jakob Graf]


0.1.13 (2024-01-28)
-------------------
- Release: version 0.1.13 🚀 [Jakob Graf]
- Bug: timing plugin. [Jakob Graf]


0.1.12 (2024-01-28)
-------------------
- Release: version 0.1.12 🚀 [Jakob Graf]
- Feat: timing plugin. [Jakob Graf]


0.1.11 (2024-01-28)
-------------------
- Release: version 0.1.11 🚀 [Jakob Graf]
- Feat: new version. [Jakob Graf]
- Bug: version and exit. [Jakob Graf]


0.1.10 (2024-01-28)
-------------------
- Release: version 0.1.10 🚀 [Jakob Graf]
- Feat: support windows commnds. [Jakob Graf]
- Feat: make version printable. [Jakob Graf]


0.1.9 (2024-01-28)
------------------
- Release: version 0.1.9 🚀 [Jakob Graf]
- Feat: modify rest plugin. [Jakob Graf]
- Release: version 0.1.8 🚀 [Jakob Graf]


0.1.8 (2024-01-28)
------------------
- Release: version 0.1.8 🚀 [Jakob Graf]
- Bug: line numbers. [Jakob Graf]


0.1.7 (2024-01-17)
------------------
- Release: version 0.1.7 🚀 [Jakob Graf]
- Bug: formatting. [Jakob Graf]
- Bug: types. [Jakob Graf]
- Feat: improve rest plugin. [Jakob Graf]
- Bug: formatting. [Jakob Graf]
- Feat: line numbers on errors. [Jakob Graf]
- Bug: minor bug fixes and formatting. [Jakob Graf]
- Feat: improve logging and formatting. [Jakob Graf]


0.1.6 (2024-01-16)
------------------
- Release: version 0.1.6 🚀 [Jakob Graf]
- Feat: ssh cmd assertion. [Jakob Graf]
- Feat: fail fast. [Jakob Graf]


0.1.5 (2024-01-16)
------------------
- Release: version 0.1.5 🚀 [Jakob Graf]
- Bug: code formatting. [Jakob Graf]
- Bug: variable replacement. [Jakob Graf]
- Feat: create sql plus plugin. [Jakob Graf]
- Feat: cleanup code. [Jakob Graf]
- Aktualisieren von README.md. [Graf Jakob]
- Aktualisieren von README.md. [Graf Jakob]
- Aktualisieren von README.md. [Graf Jakob]


0.1.4 (2023-12-16)
------------------
- Release: version 0.1.4 🚀 [Jakob Graf]
- Feat: selenium plugin. [Jakob Graf]
- Merge pull request #3 from
  jackovsky8/dependabot/github_actions/actions/setup-python-5. [Graf
  Jakob]

  build(deps): bump actions/setup-python from 4 to 5
- Build(deps): bump actions/setup-python from 4 to 5. [dependabot[bot]]

  Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4 to 5.
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: actions/setup-python
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...


0.1.3 (2023-11-27)
------------------
- Release: version 0.1.3 🚀 [Jakob Graf]
- Feat: ssh command accept different return codes. [Jakob Graf]
- Feat: improve and rename bash cmd plugin. [Jakob Graf]


0.1.2 (2023-11-27)
------------------
- Release: version 0.1.2 🚀 [Jakob Graf]
- Bug: setup. [Jakob Graf]
- Feat: assert plugin. [Jakob Graf]
- Feat: read jar manifest. [Jakob Graf]
- Feat: read jar manifest. [Jakob Graf]
- Feat: support dict and list in data. [Jakob Graf]
- Bug: get folder attributes for files. [Jakob Graf]
- Feat: Aktualisieren von README.md. [Graf Jakob]
- Feat: Aktualisieren von README.md. [Graf Jakob]
- Feat: Aktualisieren von README.md. [Graf Jakob]
- Copyright Notices. [Graf Jakob]
- Update LICENSE. [Graf Jakob]


0.1.1 (2023-11-23)
------------------
- Release: version 0.1.1 🚀 [Jakob Graf]


0.1.0 (2023-11-23)
------------------
- Release: version 0.1.0 🚀 [Jakob Graf]
- Feat: update readme. [Jakob Graf]
- Feat: Rename Package. [Jakob Graf]
- Release: version 0.1.0 🚀 [Jakob Graf]
- Feat: Rename Package. [Jakob Graf]
- Release: version 0.1.0 🚀 [Jakob Graf]
- Feat: Rename Package. [Jakob Graf]
- Release: version 0.1.0 🚀 [Jakob Graf]
- Feat: Remove Pyinstaller. [Jakob Graf]
- Feat: Make plugins lazy loadable. [Jakob Graf]
- Aktualisieren von README.md. [Graf Jakob]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI cleanup. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Graf Jakob]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI code coverage. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI disable tests. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Improve CI. [Jakob Graf]
- Feat: Badge package. [Jakob Graf]
- Feat: Build Linux application. [Jakob Graf]
- Feat: Cleanup scripts. [Jakob Graf]
- Feat: Base Functions. [Jakob Graf]
- Add functionality. [Jakob Graf]
- Add plugins. [Jakob Graf]
- Merge pull request #2 from
  jackovsky8/dependabot/github_actions/actions/checkout-4. [Graf Jakob]

  Bump actions/checkout from 3 to 4
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump actions/checkout from 3 to 4. [dependabot[bot]]

  Bumps [actions/checkout](https://github.com/actions/checkout) from 3 to 4.
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: actions/checkout
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #1 from
  jackovsky8/dependabot/github_actions/stefanzweifel/git-auto-commit-
  action-5. [Graf Jakob]

  Bump stefanzweifel/git-auto-commit-action from 4 to 5
- ✅ Ready to clone and code. [dependabot[bot]]
- Bump stefanzweifel/git-auto-commit-action from 4 to 5.
  [dependabot[bot]]

  Bumps [stefanzweifel/git-auto-commit-action](https://github.com/stefanzweifel/git-auto-commit-action) from 4 to 5.
  - [Release notes](https://github.com/stefanzweifel/git-auto-commit-action/releases)
  - [Changelog](https://github.com/stefanzweifel/git-auto-commit-action/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/stefanzweifel/git-auto-commit-action/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: stefanzweifel/git-auto-commit-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- ✅ Ready to clone and code. [jackovsky8]
- Initial commit. [Graf Jakob]


